searchData={"content_type":"text/markdown","items":[{"doc":"A function to customize json. Receives a current result and a resource record.","ref":"dsl-ashjason-resource.html#jason-customize","title":"AshJason.Resource.jason.customize","type":"DSL"},{"doc":"A map to merge into json.","ref":"dsl-ashjason-resource.html#jason-merge","title":"AshJason.Resource.jason.merge","type":"DSL"},{"doc":"Keys to pick from a record into json. Either an explicit names list or a behaviour configuration map.","ref":"dsl-ashjason-resource.html#jason-pick","title":"AshJason.Resource.jason.pick","type":"DSL"},{"doc":"Configuration for Jason encoder implementation","ref":"dsl-ashjason-resource.html#jason","title":"AshJason.Resource.jason","type":"DSL"},{"doc":"Ash resource extension for implementing `Jason.Encoder` protocol.","ref":"AshJason.Resource.html","title":"AshJason.Resource","type":"module"},{"doc":"# AshJason\n\n[![Module Version](https://img.shields.io/hexpm/v/ash_jason)](https://hex.pm/packages/ash_jason)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen)](https://hexdocs.pm/ash_jason/)\n[![License](https://img.shields.io/hexpm/l/ash_jason)](https://github.com/vonagam/ash_jason/blob/master/LICENSE.md)\n\nAsh resource extension for implementing `Jason.Encoder` protocol.","ref":"readme.html","title":"Guide","type":"extras"},{"doc":"Add to the deps, get deps (`mix deps.get`), compile them (`mix deps.compile`).\n\n```elixir\ndef deps do\n  [\n    {:ash_jason, \"~> 1.0.1\"},\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - Guide","type":"extras"},{"doc":"Add `AshJason.Resource` to `extensions` list within `use Ash.Resource` options:\n\n```elixir\ndefmodule Example.Resource do\n  use Ash.Resource,\n    extensions: [AshJason.Resource]\nend\n```","ref":"readme.html#usage","title":"Usage - Guide","type":"extras"},{"doc":"The process to get data for json happens with three steps: \n- Pick keys from a record.\n- Merge some fixed values.\n- Customize a result.\n\nBy default only first step happens and it picks all non-private fields (attributes, relationships, aggregates,\ncalculations) with loaded non-nil values.\n\nFor configuration there is an optional `jason` dsl section:\n\n```elixir\ndefmodule Example.Resource do\n  use Ash.Resource,\n    extensions: [AshJason.Resource]\n\n  jason do\n    # options\n  end\nend\n```\n\n#### pick\n\nKeys to pick from a record and include in json.\nValues of `nil`/`Ash.NotLoaded`/`Ash.ForbiddenField` are omitted.\n\nCan be specified as a fixed explicit list of keys or a map with a configuration of default behaviour.\n\nMap can have such options as:\n- `private?` - Whenever to pick private fields.\n- `sensitive?` - Whenever to pick sensitive fields.\n- `include` - Keys to pick. In addition to fields.\n- `exclude` - Keys not to pick. \n\n```elixir\njason do\n  # Pick only those listed keys\n  pick [:only_some_field]\n\n  # Pick non-sensitive fields\n  pick %{private?: true}\n\n  # Pick non-private fields\n  pick %{sensitive?: true}\n\n  # Pick all fields\n  pick %{private?: true, sensitive?: true}\n\n  # Pick usual but include and exclude some specific keys\n  pick %{include: [:ok_private_field], exclude: [:irrelevant_public_field]}\nend\n```\n\n#### merge\n\nA map to merge into json.\n\n```elixir\njason do\n  merge %{merged_key: \"merged_value\"}\nend\n```\n\n#### customize\n\nA function to customize json.\nReceives a current resulted json map and a source resource record.\nReturns a modified json map.\n\n```elixir\njason do\n  customize fn result, _record ->\n    result |> Map.put(:custom_key, \"custom_value\")\n  end\nend\n```","ref":"readme.html#configuration","title":"Configuration - Guide","type":"extras"},{"doc":"[`Jason` docs](https://hexdocs.pm/jason).","ref":"readme.html#links","title":"Links - Guide","type":"extras"},{"doc":"MIT License\n\nCopyright (c) 2023 Dmitry Maganov\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html","title":"License","type":"extras"},{"doc":"<!--\nThis file was generated by Spark. Do not edit it by hand.\n-->\n# DSL: AshJason.Resource\n\nAsh resource extension for implementing `Jason.Encoder` protocol.","ref":"dsl-ashjason-resource.html","title":"DSL: AshJason.Resource","type":"extras"},{"doc":"Configuration for Jason encoder implementation","ref":"dsl-ashjason-resource.html#jason","title":"jason - DSL: AshJason.Resource","type":"extras"},{"doc":"| Name | Type | Default | Docs |\n|------|------|---------|------|\n| [`pick`](#jason-pick){: #jason-pick } | `list(atom) \\| %{optional(:private?) => boolean, optional(:sensitive?) => boolean, optional(:include) => list(atom), optional(:exclude) => list(atom)}` |  | Keys to pick from a record into json. Either an explicit names list or a behaviour configuration map. |\n| [`merge`](#jason-merge){: #jason-merge } | `map` |  | A map to merge into json. |\n| [`customize`](#jason-customize){: #jason-customize } | `(map, map -> map)` |  | A function to customize json. Receives a current result and a resource record. |\n\n\n\n\n\n\n\n .spark-required::after { content: \"*\"; color: red !important; }","ref":"dsl-ashjason-resource.html#options","title":"Options - DSL: AshJason.Resource","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,50,46,50]}}